@@ -107,7 +107,7 @@ class ReturnList(list):
     def __reduce__(self):
         # Pickling these objects will drop the .serializer backlink,
         # but preserve the raw data.
-        return (list, (list(self),))
+        return list, (list(self),)
 
 
 class ReturnDict(OrderedDict):
@@ -130,35 +130,49 @@ class ReturnDict(OrderedDict):
     def __reduce__(self):
         # Pickling these objects will drop the .serializer backlink,
         # but preserve the raw data.
-        return (dict, (dict(self),))
+        return dict, (dict(self),)
 
 
 class DictMapper(dict):
-    """
-    This is a dict-like object that exposes keys as attributes.
-    """
-
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        for key in self:
-            self.__dict__[key] = self[key]
+        super(DictMapper, self).__init__(*args, **kwargs)
+        for arg in args:
+            if isinstance(arg, dict):
+                for k, v in arg.items():
+                    if isinstance(v, dict):
+                        v = DictMapper(v)
+                    if isinstance(v, list):
+                        self.__convert(v)
+                    self[k] = v
+
+        if kwargs:
+            for k, v in kwargs.items():
+                if isinstance(v, dict):
+                    v = DictMapper(v)
+                elif isinstance(v, list):
+                    self.__convert(v)
+                self[k] = v
+
+    def __convert(self, v):
+        for elem in range(0, len(v)):
+            if isinstance(v[elem], dict):
+                v[elem] = DictMapper(v[elem])
+            elif isinstance(v[elem], list):
+                self.__convert(v[elem])
+
+    def __getattr__(self, attr):
+        return self.get(attr)
 
     def __setattr__(self, key, value):
-        self[key] = value
-
-    def __delattr__(self, key):
-        del self[key]
-
-    def __getattr__(self, key):
-        return self[key]
+        self.__setitem__(key, value)
 
     def __setitem__(self, key, value):
-        super().__setitem__(key, value)
-        self.__dict__[key] = value
+        super(DictMapper, self).__setitem__(key, value)
+        self.__dict__.update({key: value})
+
+    def __delattr__(self, item):
+        self.__delitem__(item)
 
     def __delitem__(self, key):
-        super().__delitem__(key)
+        super(DictMapper, self).__delitem__(key)
         del self.__dict__[key]
-
-    def __repr__(self):
-        return dict.__repr__(self)
